@@ -1,24 +1,24 @@
 ########################################################################
 # This file introduces a common framework to ask whether or not a given
 # property (which is potentially hard to compute) is known for some
-# object `x`. 
+# object `x`.
 ########################################################################
 
 @doc raw"""
     is_known(f::Function, args...; kwargs...)
 
-Given a function `f`, arguments `args`, and potentially keyword arguments 
-`kwargs`, return whether `f(args...; kwargs...)` is "known" in the sense that 
+Given a function `f`, arguments `args`, and potentially keyword arguments
+`kwargs`, return whether `f(args...; kwargs...)` is "known" in the sense that
 evaluating `f(args...; kwargs...)` is fast and takes constant time.
 
-For example this might return `true` if `f(args...; kwargs...)` was computed 
+For example this might return `true` if `f(args...; kwargs...)` was computed
 before and has been cached.
 
 Note: There is no default implementation. In general for `is_known` to work correctly
 for a given function `f` requires that everyone adding, modifying or removing
-methods for `f` adjusts the corresponding methods for `is_known(::typeof(f), ...)` 
-as needed. That is, they are responsible for ensuring `is_known(f, args...; kwargs...)` 
-returns an appropriate result whenever `f(args...; kwargs...)` would invoke the method 
+methods for `f` adjusts the corresponding methods for `is_known(::typeof(f), ...)`
+as needed. That is, they are responsible for ensuring `is_known(f, args...; kwargs...)`
+returns an appropriate result whenever `f(args...; kwargs...)` would invoke the method
 they just added or modified, resp. would have invoked a method they removed.
 
 Conversely this means that `is_known` does not work for an arbitrary
@@ -42,11 +42,3 @@ ERROR: MethodError: no method matching is_known(::typeof(dim), ::AbstractAlgebra
 ```
 """
 function is_known end
-
-# A generic implementation to look up attributes. This can be used to implement 
-# `is_known` for a specific type of arguments of unary functions.
-function _is_known_via_attributes(f::Function, x::Any)
-  @req is_attribute_storing(x) "objects of type $(typeof(x)) do not support attribute storage"
-  return has_attribute(x, nameof(f))
-end
-
