@@ -5,19 +5,10 @@ function gen(L::SimpleNumField{T}, i::Int) where {T}
    return gen(L)
 end
 
-function Base.getindex(L::SimpleNumField{T}, i::Int) where {T}
-   if i == 0
-      return one(L)
-   elseif i == 1
-      return gen(L)
-   else
-      error("index has to be 0 or 1")
-   end
-end
-
 number_of_generators(L::SimpleNumField{T}) where {T} = 1
 
 characteristic(F::NumField) = 0
+is_known(::typeof(characteristic), F::NumField) = true
 
 promote_rule(::Type{T}, ::Type{S}) where {S<:NumFieldElem,T<:Integer} = S
 
