@@ -64,24 +64,8 @@ function modulus(r::ResFieldElem)
    return modulus(parent(r))
 end
 
-@doc raw"""
-    characteristic(R::ResidueField)
-
-Return the characteristic of the residue field.
-"""
-function characteristic(R::ResidueField)
-   return characteristic(base_ring(R))
-end
-
-@doc raw"""
-    characteristic(r::ResidueField{T}) where T <: Integer
-
-Return the modulus $a$ of the residue ring $S = R/(a)$ that the supplied
-residue $r$ belongs to.
-"""
-function characteristic(r::ResidueField{T}) where T <: Integer
-   return modulus(r)
-end
+characteristic(r::ResidueField{T}) where T <: Integer = modulus(r)
+is_known(::typeof(characteristic), R::ResidueField{T}) where T <: Integer = true
 
 data(a::ResFieldElem) = a.data
 
@@ -457,7 +441,7 @@ end
 @doc raw"""
     quo(::Type{Field}, R::Ring, a::RingElement; cached::Bool = true)
 
-Returns `S, f` where `S = residue_field(R, a)` and `f` is the 
+Returns `S, f` where `S = residue_field(R, a)` and `f` is the
 projection map from `R` to `S`. This map is supplied as a map with section
 where the section is the lift of an element of the residue field back
 to the ring `R`.
