@@ -72,11 +72,11 @@ function _numpart(n::Integer)
    elseif n < 395
       return _numpart(Int(n), _numPartsTable)
    else
-      return _numpart(BigInt(n), _numPartsTableBig)
+      return _numpart(Int(n), _numPartsTableBig)
    end
 end
 
-function _numpart(n::T, lookuptable::Dict{Int, T}) where T<:Integer
+function _numpart(n::Int, lookuptable::Dict{Int, T}) where T<:Integer
    s = zero(T)
    if !haskey(lookuptable, n)
       for j in 1:floor(T, (1 + Base.sqrt(1 + 24n))/6)
@@ -411,7 +411,7 @@ const _border = Dict{Symbol,String}(
 
 :cross => "┼")
 
-function boxed_str(Y::YoungTableau, fill=Y.fill)
+function boxed_str(Y::YoungTableau, fill::Vector{<:Integer}=Y.fill)
    r,c = size(Y)
    w = max(length(string(maximum(fill))), 3)
    horizontal = repeat(_border[:horizontal], w)
