@@ -99,13 +99,6 @@ end
 
    @test isa(l, Generic.RelSeries)
 
-   @test x in [x, y]
-   @test x in [y, x]
-   @test !(x in [y])
-
-   @test x in keys(Dict(x => 1))
-   @test !(y in keys(Dict(x => 1)))
-
    @test_throws DomainError O(0+O(x^0))
 
    @test !occursin("\n", sprint(show, T))
@@ -258,7 +251,7 @@ end
    @test isa(r, RelPowerSeriesRingElem)
 
    s = rel_series(ZZ, [1, 2, 3], 3, 5, 0; max_precision=10)
-   
+
    @test max_precision(parent(s)) == 10
 end
 
@@ -824,7 +817,7 @@ end
     for iter = 1:300
         f1 = rand(R, 0:10, -10:10)
         f2 = rand(R, 0:10, -10:10)
-     
+
         g = rand(R, 1:10, -10:10)
 
         @test compose(f1 + f2, g; inner = :second) == compose(f1, g; inner = :second) + compose(f2, g; inner = :second)
@@ -1258,7 +1251,7 @@ end
 @testset "Generic.RelSeries.unsafe_operators" begin
    # Exact ring
    R, x = power_series_ring(ZZ, 10, "x")
-   
+
    for iter = 1:300
       f = rand(R, 0:9, -10:10)
       g = rand(R, 0:9, -10:10)
@@ -1292,8 +1285,8 @@ end
       h = mul!(h, f, g)
       @test isequal(h, k)
       @test isequal(f, f0)
-      @test isequal(g, g0)      
-     
+      @test isequal(g, g0)
+
       f1 = deepcopy(f)
       f1 = mul!(f1, f1, g)
       @test isequal(f1, k)
